==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/CheckedChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CheckedChangedEventArgsDescription } from "./CheckedChangedEventArgsDescription";
/**
 * @hidden
 */
export let CheckedChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CheckedChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CheckedChangedEventArgsDescriptionMetadata.a == null) {
                CheckedChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CheckedChangedEventArgsDescriptionMetadata.c(CheckedChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(CheckedChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(CheckedChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Index", "Number:int");
            a.item("IsChecked", "Boolean");
        }
        static d(a) {
            CheckedChangedEventArgsDescriptionMetadata.b(a);
            a.ad("CheckedChangedEventArgs", () => new CheckedChangedEventArgsDescription());
            a.ac("CheckedChangedEventArgs", CheckedChangedEventArgsDescriptionMetadata.a);
        }
    }
    CheckedChangedEventArgsDescriptionMetadata.$t = markType(CheckedChangedEventArgsDescriptionMetadata, 'CheckedChangedEventArgsDescriptionMetadata');
    CheckedChangedEventArgsDescriptionMetadata.a = null;
    return CheckedChangedEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/CheckedChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CheckedChangedEventArgsDescription } from "./CheckedChangedEventArgsDescription";
/**
 * @hidden
 */
export let CheckedChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CheckedChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CheckedChangedEventArgsDescriptionMetadata.a == null) {
                CheckedChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CheckedChangedEventArgsDescriptionMetadata.c(CheckedChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(CheckedChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(CheckedChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Index", "Number:int");
            a.item("IsChecked", "Boolean");
            a.item("PrimaryKeyRef", "(w:PrimaryKey,wf:PrimaryKey)DataRef:object");
        }
        static d(a) {
            CheckedChangedEventArgsDescriptionMetadata.b(a);
            a.ae("CheckedChangedEventArgs", () => new CheckedChangedEventArgsDescription());
            a.ad("CheckedChangedEventArgs", CheckedChangedEventArgsDescriptionMetadata.a);
        }
    }
    CheckedChangedEventArgsDescriptionMetadata.$t = markType(CheckedChangedEventArgsDescriptionMetadata, 'CheckedChangedEventArgsDescriptionMetadata');
    CheckedChangedEventArgsDescriptionMetadata.a = null;
    return CheckedChangedEventArgsDescriptionMetadata;
})();
